$def with (page, title='Shoal | Realtime Squid Monitoring System')
<!DOCTYPE html>
<html lang="en">
    <head>
      <meta http-equiv="refresh" content="30" />
      <meta charset="utf-8">
    <title>
        $if title:$title\
    </title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- Le styles -->
    <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    <style>
      body {
        padding-top: 60px; /* 60px to make the container go all the way to the bottom of the topbar */
      }
    </style>
    <link href="/static/css/bootstrap-responsive.min.css" rel="stylesheet">
    <link href="/static/img/icons/favicon.ico" rel="shortcut icon" type="image/x-icon">
    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="/static/js/html5shiv.js"></script>
    <![endif]-->

    <!-- Fav and touch icons -->
  </head>

  <body>
    <div class="navbar navbar-inverse navbar-fixed-top">
      <div class="navbar-inner">
        <div class="container">
          <button type="button" class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="brand" href='#'>Shoal</a>
          <div class="nav-collapse collapse">
            <ul class="nav">
              <li class="active"><a href="#">Latest</a></li>
              <li><a href="/nearest">Nearest Squid</a></li>
            </ul>
          </div><!--/.nav-collapse -->
        </div>
      </div>
    </div>

    <div class="container-fluid">
      <div class="row-fluid">
        $:page
      </div>
      <hr>
      <div class="row-fluid">
        <div class="span12">
          <footer id="footer" style="text-align:center">
            &copy; University of Victoria  ||  <a href="http://github.com/hep-gc/shoal">Visit GitHub Project</a><i class="icon-hand-up"></i>
          </footer>
        </div>
      </div>
    </div> <!-- /container -->
    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="/static/js/jquery.min.js"></script>
    <script src="/static/js/bootstrap.min.js"></script>
  </body>
</html>

